"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FeatureToggleServiceComponent = void 0;
const tslib_1 = require("tslib");
// Copyright (c) 2023 Sourcefuse Technologies
//
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT
const core_1 = require("@loopback/core");
const rest_1 = require("@loopback/rest");
const core_2 = require("@sourceloop/core");
const loopback4_authentication_1 = require("loopback4-authentication");
const loopback4_authorization_1 = require("loopback4-authorization");
const controllers_1 = require("./controllers");
const keys_1 = require("./keys");
const models_1 = require("./models");
const repositories_1 = require("./repositories");
let FeatureToggleServiceComponent = class FeatureToggleServiceComponent {
    constructor(application, config) {
        var _a;
        this.application = application;
        this.config = config;
        this.providers = {};
        this.bindings = [];
        this.bindings = [];
        // Mount core component
        this.application.component(core_2.CoreComponent);
        this.application.api({
            openapi: '3.0.0',
            info: {
                title: 'Feature Toggle Service',
                version: '1.0.0',
            },
            paths: {},
            components: {
                securitySchemes: core_2.SECURITY_SCHEME_SPEC,
            },
            servers: [{ url: '/' }],
        });
        // Mount default sequence if needed
        if (!((_a = this.config) === null || _a === void 0 ? void 0 : _a.useCustomSequence)) {
            // Mount default sequence if needed
            this.setupSequence();
        }
        this.repositories = [
            repositories_1.FeatureRepository,
            repositories_1.FeatureValuesRepository,
            repositories_1.StrategyRepository,
        ];
        this.models = [models_1.Feature, models_1.FeatureValues, models_1.Strategy];
        this.controllers = [
            controllers_1.FeatureController,
            controllers_1.FeatureValuesController,
            controllers_1.StrategyController,
        ];
    }
    setupSequence() {
        this.application.sequence(core_2.ServiceSequence);
        // Mount authentication component for default sequence
        this.application.component(loopback4_authentication_1.AuthenticationComponent);
        // Mount bearer verifier component
        this.application.bind(core_2.BearerVerifierBindings.Config).to({
            authServiceUrl: '',
            type: core_2.BearerVerifierType.service,
        });
        this.application.component(core_2.BearerVerifierComponent);
        // Mount authorization component for default sequence
        this.application.bind(loopback4_authorization_1.AuthorizationBindings.CONFIG).to({
            allowAlwaysPaths: ['/explorer'],
        });
        this.application.component(loopback4_authorization_1.AuthorizationComponent);
    }
};
exports.FeatureToggleServiceComponent = FeatureToggleServiceComponent;
exports.FeatureToggleServiceComponent = FeatureToggleServiceComponent = tslib_1.__decorate([
    tslib_1.__param(0, (0, core_1.inject)(core_1.CoreBindings.APPLICATION_INSTANCE)),
    tslib_1.__param(1, (0, core_1.inject)(keys_1.FeatureToggleBindings.Config, { optional: true })),
    tslib_1.__metadata("design:paramtypes", [rest_1.RestApplication, Object])
], FeatureToggleServiceComponent);
//# sourceMappingURL=component.js.map