"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FeatureValuesController = void 0;
const tslib_1 = require("tslib");
// Copyright (c) 2023 Sourcefuse Technologies
//
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT
const repository_1 = require("@loopback/repository");
const rest_1 = require("@loopback/rest");
const core_1 = require("@sourceloop/core");
const loopback4_authentication_1 = require("loopback4-authentication");
const loopback4_authorization_1 = require("loopback4-authorization");
const enums_1 = require("../enums");
const models_1 = require("../models");
const repositories_1 = require("../repositories");
const basePath = '/feature-values';
let FeatureValuesController = class FeatureValuesController {
    constructor(featureValuesRepository) {
        this.featureValuesRepository = featureValuesRepository;
    }
    async create(featureValues) {
        return this.featureValuesRepository.create(featureValues);
    }
    async count(where) {
        return this.featureValuesRepository.count(where);
    }
    async find(filter) {
        return this.featureValuesRepository.find(filter);
    }
    async updateAll(featureValues, where) {
        return this.featureValuesRepository.updateAll(featureValues, where);
    }
    async findById(id, filter) {
        return this.featureValuesRepository.findById(id, filter);
    }
    async updateById(id, featureValues) {
        await this.featureValuesRepository.updateById(id, featureValues);
    }
    async replaceById(id, featureValues) {
        await this.featureValuesRepository.replaceById(id, featureValues);
    }
    async deleteById(id) {
        await this.featureValuesRepository.deleteById(id);
    }
};
exports.FeatureValuesController = FeatureValuesController;
tslib_1.__decorate([
    (0, loopback4_authentication_1.authenticate)("bearer" /* STRATEGY.BEARER */),
    (0, loopback4_authorization_1.authorize)({
        permissions: [
            enums_1.PermissionKey.CreateFeatureValues,
            enums_1.PermissionKey.CreateFeatureValuesNum,
        ],
    }),
    (0, rest_1.post)(basePath, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* STATUS_CODE.OK */]: {
                description: 'FeatureValues model instance',
                content: {
                    [core_1.CONTENT_TYPE.JSON]: { schema: (0, rest_1.getModelSchemaRef)(models_1.FeatureValues) },
                },
            },
        },
    }),
    tslib_1.__param(0, (0, rest_1.requestBody)({
        content: {
            [core_1.CONTENT_TYPE.JSON]: {
                schema: (0, rest_1.getModelSchemaRef)(models_1.FeatureValues, {
                    title: 'NewFeatureValues',
                }),
            },
        },
    })),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [models_1.FeatureValues]),
    tslib_1.__metadata("design:returntype", Promise)
], FeatureValuesController.prototype, "create", null);
tslib_1.__decorate([
    (0, loopback4_authentication_1.authenticate)("bearer" /* STRATEGY.BEARER */),
    (0, loopback4_authorization_1.authorize)({
        permissions: [
            enums_1.PermissionKey.ViewFeatureValues,
            enums_1.PermissionKey.ViewFeatureValuesNum,
        ],
    }),
    (0, rest_1.get)(`${basePath}/count`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* STATUS_CODE.OK */]: {
                description: 'FeatureValues model count',
                content: { [core_1.CONTENT_TYPE.JSON]: { schema: repository_1.CountSchema } },
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.where(models_1.FeatureValues)),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object]),
    tslib_1.__metadata("design:returntype", Promise)
], FeatureValuesController.prototype, "count", null);
tslib_1.__decorate([
    (0, loopback4_authentication_1.authenticate)("bearer" /* STRATEGY.BEARER */),
    (0, loopback4_authorization_1.authorize)({
        permissions: [
            enums_1.PermissionKey.ViewFeatureValues,
            enums_1.PermissionKey.ViewFeatureValuesNum,
        ],
    }),
    (0, rest_1.get)(basePath, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* STATUS_CODE.OK */]: {
                description: 'Array of FeatureValues model instances',
                content: {
                    [core_1.CONTENT_TYPE.JSON]: {
                        schema: {
                            type: 'array',
                            items: (0, rest_1.getModelSchemaRef)(models_1.FeatureValues, { includeRelations: true }),
                        },
                    },
                },
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.filter(models_1.FeatureValues)),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [Object]),
    tslib_1.__metadata("design:returntype", Promise)
], FeatureValuesController.prototype, "find", null);
tslib_1.__decorate([
    (0, loopback4_authentication_1.authenticate)("bearer" /* STRATEGY.BEARER */),
    (0, loopback4_authorization_1.authorize)({
        permissions: [
            enums_1.PermissionKey.UpdateFeatureValues,
            enums_1.PermissionKey.UpdateFeatureValuesNum,
        ],
    }),
    (0, rest_1.patch)(basePath, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* STATUS_CODE.OK */]: {
                description: 'FeatureValues PATCH success count',
                content: { [core_1.CONTENT_TYPE.JSON]: { schema: repository_1.CountSchema } },
            },
        },
    }),
    tslib_1.__param(0, (0, rest_1.requestBody)({
        content: {
            [core_1.CONTENT_TYPE.JSON]: {
                schema: (0, rest_1.getModelSchemaRef)(models_1.FeatureValues, { partial: true }),
            },
        },
    })),
    tslib_1.__param(1, rest_1.param.where(models_1.FeatureValues)),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [models_1.FeatureValues, Object]),
    tslib_1.__metadata("design:returntype", Promise)
], FeatureValuesController.prototype, "updateAll", null);
tslib_1.__decorate([
    (0, loopback4_authentication_1.authenticate)("bearer" /* STRATEGY.BEARER */),
    (0, loopback4_authorization_1.authorize)({
        permissions: [
            enums_1.PermissionKey.ViewFeatureValues,
            enums_1.PermissionKey.ViewFeatureValuesNum,
        ],
    }),
    (0, rest_1.get)(`${basePath}/{id}`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [200 /* STATUS_CODE.OK */]: {
                description: 'FeatureValues model instance',
                content: {
                    [core_1.CONTENT_TYPE.JSON]: {
                        schema: (0, rest_1.getModelSchemaRef)(models_1.FeatureValues, { includeRelations: true }),
                    },
                },
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.path.string('id')),
    tslib_1.__param(1, rest_1.param.filter(models_1.FeatureValues, { exclude: 'where' })),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [String, Object]),
    tslib_1.__metadata("design:returntype", Promise)
], FeatureValuesController.prototype, "findById", null);
tslib_1.__decorate([
    (0, loopback4_authentication_1.authenticate)("bearer" /* STRATEGY.BEARER */),
    (0, loopback4_authorization_1.authorize)({
        permissions: [
            enums_1.PermissionKey.UpdateFeatureValues,
            enums_1.PermissionKey.UpdateFeatureValuesNum,
        ],
    }),
    (0, rest_1.patch)(`${basePath}/{id}`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [204 /* STATUS_CODE.NO_CONTENT */]: {
                description: 'FeatureValues PATCH success',
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.path.string('id')),
    tslib_1.__param(1, (0, rest_1.requestBody)({
        content: {
            [core_1.CONTENT_TYPE.JSON]: {
                schema: (0, rest_1.getModelSchemaRef)(models_1.FeatureValues, { partial: true }),
            },
        },
    })),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [String, models_1.FeatureValues]),
    tslib_1.__metadata("design:returntype", Promise)
], FeatureValuesController.prototype, "updateById", null);
tslib_1.__decorate([
    (0, loopback4_authentication_1.authenticate)("bearer" /* STRATEGY.BEARER */),
    (0, loopback4_authorization_1.authorize)({
        permissions: [
            enums_1.PermissionKey.UpdateFeatureValues,
            enums_1.PermissionKey.UpdateFeatureValuesNum,
        ],
    }),
    (0, rest_1.put)(`${basePath}/{id}`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [204 /* STATUS_CODE.NO_CONTENT */]: {
                description: 'FeatureValues PUT success',
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.path.string('id')),
    tslib_1.__param(1, (0, rest_1.requestBody)()),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [String, models_1.FeatureValues]),
    tslib_1.__metadata("design:returntype", Promise)
], FeatureValuesController.prototype, "replaceById", null);
tslib_1.__decorate([
    (0, loopback4_authentication_1.authenticate)("bearer" /* STRATEGY.BEARER */),
    (0, loopback4_authorization_1.authorize)({
        permissions: [
            enums_1.PermissionKey.DeleteFeatureValues,
            enums_1.PermissionKey.DeleteFeatureValuesNum,
        ],
    }),
    (0, rest_1.del)(`${basePath}/{id}`, {
        security: core_1.OPERATION_SECURITY_SPEC,
        responses: {
            [204 /* STATUS_CODE.NO_CONTENT */]: {
                description: 'FeatureValues DELETE success',
            },
        },
    }),
    tslib_1.__param(0, rest_1.param.path.string('id')),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", [String]),
    tslib_1.__metadata("design:returntype", Promise)
], FeatureValuesController.prototype, "deleteById", null);
exports.FeatureValuesController = FeatureValuesController = tslib_1.__decorate([
    tslib_1.__param(0, (0, repository_1.repository)(repositories_1.FeatureValuesRepository)),
    tslib_1.__metadata("design:paramtypes", [repositories_1.FeatureValuesRepository])
], FeatureValuesController);
//# sourceMappingURL=feature-values.controller.js.map